@@ -8,13 +8,18 @@ use crate::{
     mit::{Author, Authors},
 };
 
+/// An in memory vcs implementation
+///
+/// Mostly used for testing
+#[derive(Debug)]
 pub struct InMemory<'a> {
     store: &'a mut BTreeMap<String, String>,
 }
 
 impl InMemory<'_> {
+    /// Create a new in memory vcs
     #[must_use]
-    pub fn new(store: &mut BTreeMap<String, String>) -> InMemory {
+    pub fn new(store: &mut BTreeMap<String, String>) -> InMemory<'_> {
         InMemory { store }
     }
 }
@@ -69,10 +74,10 @@ impl Vcs for InMemory<'_> {
     }
 }
 
-impl TryFrom<&'_ InMemory<'_>> for Authors {
+impl TryFrom<&'_ InMemory<'_>> for Authors<'_> {
     type Error = Report;
 
-    fn try_from(vcs: &'_ InMemory) -> Result<Self, Self::Error> {
+    fn try_from(vcs: &'_ InMemory<'_>) -> Result<Self, Self::Error> {
         let raw_entries: BTreeMap<String, BTreeMap<String, String>> = vcs
             .entries(Some("mit.author.config.*"))?
             .iter()
@@ -104,17 +109,18 @@ impl TryFrom<&'_ InMemory<'_>> for Authors {
 
                     match (name, email, signingkey) {
                         (Some(name), Some(email), None) => {
-                            Some((key, Author::new(&name, &email, None)))
-                        }
-                        (Some(name), Some(email), Some(signingkey)) => {
-                            Some((key, Author::new(&name, &email, Some(&signingkey))))
+                            Some((key, Author::new(name.into(), email.into(), None)))
                         }
+                        (Some(name), Some(email), Some(signingkey)) => Some((
+                            key,
+                            Author::new(name.into(), email.into(), Some(signingkey.into())),
+                        )),
                         _ => None,
                     }
                 })
                 .fold(
                     BTreeMap::new(),
-                    |mut acc: BTreeMap<String, Author>, (key, value): (&String, Author)| {
+                    |mut acc: BTreeMap<String, Author<'_>>, (key, value): (&String, Author<'_>)| {
                         acc.insert(key.clone(), value);
                         acc
                     },
